@@ -39,7 +39,8 @@
 #' gbif_downstream(key = 7799978, downto="species", intermediate=TRUE)
 #' 
 #' # names that don't have canonicalname entries for some results
-#' key <- get_gbifid("Myosotis")
+#' # Myosotis: key 2925668
+#' key <- 2925668
 #' res <- gbif_downstream(key, downto = "species")
 #' res2 <- downstream(key, db = "gbif", downto = "species")
 #' }
@@ -50,11 +51,12 @@ gbif_downstream <- function(key, downto, intermediate = FALSE, limit = 100,
   should_be('intermediate', intermediate, 'logical')
 
   downto <- tolower(downto)
-  poss_ranks <- unique(do.call(c, sapply(rank_ref$ranks, strsplit, split = ",",
-                                         USE.NAMES = FALSE)))
+  poss_ranks <- unique(do.call(c,
+    sapply(taxize_ds$rank_ref$ranks, strsplit, split = ",",
+      USE.NAMES = FALSE)))
   downto <- match.arg(downto, choices = poss_ranks)
-  torank <- sapply(rank_ref[which_rank(downto), "ranks"],
-                   function(x) strsplit(x, ",")[[1]][[1]], USE.NAMES = FALSE)
+  torank <- sapply(taxize_ds$rank_ref[which_rank(downto), "ranks"],
+    function(x) strsplit(x, ",")[[1]][[1]], USE.NAMES = FALSE)
 
   stop_ <- "not"
   notout <- data.frame(rank = "", stringsAsFactors = FALSE)
@@ -63,9 +65,10 @@ gbif_downstream <- function(key, downto, intermediate = FALSE, limit = 100,
   iter <- 0
   while (stop_ == "not") {
     iter <- iter + 1
-    temp <- ldply(key, function(x) gbif_name_usage_clean(x))
-    tt <- ldply(temp$key, function(x) gbif_name_usage_children(x,
-      limit = limit, start = start, ...))
+    temp <- dt2df(lapply(key, function(x) gbif_name_usage_clean(x)),
+      idcol = FALSE)
+    tt <- dt2df(lapply(temp$key, function(x) gbif_name_usage_children(x,
+      limit = limit, start = start, ...)), idcol = FALSE)
     tt <- prune_too_low(tt, downto)
 
     if (NROW(tt) == 0) {
@@ -91,7 +94,7 @@ gbif_downstream <- function(key, downto, intermediate = FALSE, limit = 100,
     if (intermediate) intermed[[iter]] <- intermed[[iter]]
   } # end while loop
 
-  tmp <- ldply(out)
+  tmp <- dt2df(out, idcol = FALSE)
   if (intermediate) {
     list(target = tmp, intermediate = intermed)
   } else {
@@ -109,7 +112,7 @@ gbif_name_usage_clean <- function(x, ...) {
 
 gbif_name_usage_children <- function(x, limit = 100, start = NULL, ...) {
   tt <- gbif_name_usage(x, data = 'children', limit = limit, start = start, ...)$results
-  rbind.fill(lapply(tt, function(z) {
+  dt2df(lapply(tt, function(z) {
     z <- z[sapply(z, length) != 0]
     df <- data.frame(z, stringsAsFactors = FALSE)
     df$rank <- tolower(df$rank)
@@ -126,5 +129,5 @@ gbif_name_usage_children <- function(x, limit = 100, start = NULL, ...) {
     dd <- stats::setNames(dd, c('name', 'rank', 'key'))
     dd$name_type <- type
     dd
-  }))
+  }), idcol = FALSE)
 }
