@@ -3,15 +3,12 @@ context("classification")
 
 # is_up <- function(seconds=3, which="itis"){
 #   itisfxn <- function(x) tryCatch(itis_ping(config=timeout(x)), error=function(e) e)
-#   eolfxn <- function(x) tryCatch(eol_ping(config=timeout(x)), error=function(e) e)
 #   switch(which,
-#          itis = !is(itisfxn(seconds), "OPERATION_TIMEDOUT"),
-#          eol = !is(eolfxn(seconds), "OPERATION_TIMEDOUT")
+#          itis = !is(itisfxn(seconds), "OPERATION_TIMEDOUT")
 #   )
 # }
 #
 # is_up()
-# is_up(which = "eol")
 # is_up(which = "ncbi")
 #
 # skip_if <- function(x){
@@ -20,14 +17,9 @@ context("classification")
 #   expect_is(classification(c("Chironomus riparius", "aaa vva"), db = 'itis', messages = FALSE), "classification")
 # }
 
-# eolids <- get_tsn(c("Chironomus riparius", "aaa vva"), messages = FALSE)
 # tpsids <- get_tpsid(sciname=c("Helianthus excubitor", "aaa vva"), messages = FALSE)
-# clas_eolids <- classification(eolids, messages = FALSE)
 # clas_tpids <- classification(tpsids, messages = FALSE)
 
-# clas_eol <- classification(c("Helianthus petiolaris Nutt.", "aaa vva"), db = 'eol')
-# names(clas_eol) <- NULL
-
 # clas_tp <- suppressMessages(classification(c("Helianthus excubitor", "aaa vva"), db = 'tropicos'))
 # names(clas_tp) <- NULL
 
@@ -45,7 +37,6 @@ test_that("classification returns the correct values and classes", {
 
 	expect_that(clas_ncbi[[2]], equals(NA))
 	expect_that(clas_itis[[2]], equals(NA))
-# 	expect_that(clas_eol[[2]], equals(NA))
 # 	expect_that(clas_tp[[2]], equals(NA))
 
 	expect_is(clas_ncbi, "classification")
@@ -56,10 +47,6 @@ test_that("classification returns the correct values and classes", {
 	expect_is(clas_itis[[1]], "data.frame")
   expect_equal(length(clas_itis), 2)
 
-# 	expect_that(clas_eol, is_a("list"))
-# 	expect_that(clas_eol[[1]], is_a("data.frame"))
-# 	expect_that(length(clas_eol), equals(2))
-
 # 	expect_that(clas_tp, is_a("classification"))
 # 	expect_that(clas_tp[[1]], is_a("data.frame"))
 # 	expect_that(length(clas_tp), equals(2))
@@ -75,7 +62,6 @@ test_that("classification returns the correct values and classes", {
   
   expect_identical(clas_uids, clas_ncbi)
   expect_equal(clas_tsns, clas_itis)
-#   expect_identical(clas_eolids, clas_ncbi)
   #### FIX THESE TWO, SHOULD BE MATCHING
 #   expect_identical(clas_tpids, clas_tp)
 })
@@ -121,14 +107,15 @@ test_that("rbind and cbind work correctly", {
   expect_gt(length(names(clc)), 50)
 })
 
+set.seed(1)
 df <- theplantlist[sample(1:nrow(theplantlist), 50), ]
 nn <- apply(df, 1, function(x) paste(x["genus"], x["species"], collapse = " "))
 
 test_that("works on a variety of names", {
   skip_on_cran()
-  
-  x <- classification(nn[1], db = "ncbi", messages = FALSE)
-  z <- classification(nn[2], db = "ncbi", messages = FALSE)
+  # browser()
+  x <- classification(nn[5], db = "ncbi", messages = FALSE)
+  z <- classification(nn[6], db = "ncbi", messages = FALSE)
 
 	expect_is(x, "classification")
 	expect_is(z, "classification")
@@ -150,7 +137,6 @@ test_that("all rank character strings are lower case (all letters)", {
   vcr::use_cassette("classification_rank_is_lowercase", {
     aa <- classification(9606, db = 'ncbi', messages = FALSE)
     bb <- classification(129313, db = 'itis', messages = FALSE)
-    #cc <- classification(57361017, db = 'eol', messages = FALSE)
     dd <- classification(2441176, db = 'gbif', messages = FALSE)
     #ee <- classification(25509881, db = 'tropicos', messages = FALSE)
     #ff <- classification("NBNSYS0000004786", db = 'nbn', messages = FALSE)
@@ -158,7 +144,6 @@ test_that("all rank character strings are lower case (all letters)", {
 
   expect_false(all(grepl("[A-Z]", aa[[1]]$rank)))
   expect_false(all(grepl("[A-Z]", bb[[1]]$rank)))
-  #expect_false(all(grepl("[A-Z]", cc[[1]]$rank)))
   expect_false(all(grepl("[A-Z]", dd[[1]]$rank)))
   #expect_false(all(grepl("[A-Z]", ee[[1]]$rank)))
   #expect_false(all(grepl("[A-Z]", ff[[1]]$rank)))
@@ -168,18 +153,16 @@ test_that("all rank character strings are lower case (all letters)", {
 test_that("rows parameter, when used, works", {
   skip_on_cran() # uses secrets
   vcr::use_cassette("classification_rows_param", {
-    a <- classification("Asdfafsfd", db = 'ncbi', rows = 1, messages = FALSE)
+    # a <- classification("Asdfafsfd", db = 'ncbi', rows = 1, messages = FALSE)
     b <- classification("Asdfafsfd", db = 'itis', rows = 1, messages = FALSE)
     d <- classification("Asdfafsfd", db = 'gbif', rows = 1, messages = FALSE)
-    e <- classification("Asdfafsfd", db = 'eol', rows = 1, messages = FALSE)
     g <- classification("Asdfafsfd", db = 'tropicos', rows = 1, messages = FALSE)
     h <- classification("Asdfafsfd", db = 'nbn', rows = 1, messages = FALSE)
   })
 
-  expect_is(a, "classification")
+  # expect_is(a, "classification")
   expect_is(b, "classification")
   expect_is(d, "classification")
-  expect_is(e, "classification")
   expect_is(g, "classification")
   expect_is(h, "classification")
 })
